@@ -1,4 +1,6 @@
 /*
+ * This file is part of Xfce (https://gitlab.xfce.org).
+ *
  * Copyright (c) 2003 Riccardo Persichetti <riccardo.persichetti@tin.it>
  * Copyright (c) 2010 Florian Rivoal <frivoal@xfce.org>
  *
@@ -24,11 +26,11 @@
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-#ifndef __MEMSWAP_H
-#define __MEMSWAP_H
+#ifndef _XFCE_SYSTEMLOAD_MEMSWAP_H_
+#define _XFCE_SYSTEMLOAD_MEMSWAP_H_
 
 #include <glib.h>
 
-gint read_memswap(gulong *, gulong *, gulong *, gulong *, gulong *, gulong *);
+gint read_memswap(gulong *mem, gulong *swap, gulong *MT, gulong *MU, gulong *ST, gulong *SU);
 
-#endif /* ndef __MEMSWAP_H */
+#endif /* _XFCE_SYSTEMLOAD_MEMSWAP_H_ */
